@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from django.conf.urls.defaults import *
+from django.conf.urls import *
 
 urlpatterns = patterns('django_ajax.views',
     url(r'^login/$', 'login', name='ajax_login'),
